richardview.built\_in\_widgets.title\_widget module
===================================================

.. automodule:: richardview.built_in_widgets.title_widget
   :members:
   :undoc-members:
   :show-inheritance:
   :private-members:
